Struct BigUint
struct BigUint { ... }
A big unsigned integer type.
Implementations
impl BigUint
fn new(digits: Vec<u32>) -> BigUintCreates and initializes a
BigUint.The base 232 digits are ordered least significant digit first.
fn from_slice(slice: &[u32]) -> BigUintCreates and initializes a
BigUint.The base 232 digits are ordered least significant digit first.
fn assign_from_slice(self: &mut Self, slice: &[u32])Assign a value to a
BigUint.The base 232 digits are ordered least significant digit first.
fn from_bytes_be(bytes: &[u8]) -> BigUintCreates and initializes a
BigUint.The bytes are in big-endian byte order.
Examples
use BigUint; assert_eq!; assert_eq!; assert_eq!; assert_eq!;fn from_bytes_le(bytes: &[u8]) -> BigUintCreates and initializes a
BigUint.The bytes are in little-endian byte order.
fn parse_bytes(buf: &[u8], radix: u32) -> Option<BigUint>Creates and initializes a
BigUint. The input slice must contain ascii/utf8 characters in [0-9a-zA-Z].radixmust be in the range2...36.The function
from_str_radixfrom theNumtrait provides the same logic for&strbuffers.Examples
use ; assert_eq!; assert_eq!; assert_eq!;fn from_radix_be(buf: &[u8], radix: u32) -> Option<BigUint>Creates and initializes a
BigUint. Eachu8of the input slice is interpreted as one digit of the number and must therefore be less thanradix.The bytes are in big-endian byte order.
radixmust be in the range2...256.Examples
use ; let inbase190 = &; let a = from_radix_be.unwrap; assert_eq!;fn from_radix_le(buf: &[u8], radix: u32) -> Option<BigUint>Creates and initializes a
BigUint. Eachu8of the input slice is interpreted as one digit of the number and must therefore be less thanradix.The bytes are in little-endian byte order.
radixmust be in the range2...256.Examples
use ; let inbase190 = &; let a = from_radix_be.unwrap; assert_eq!;fn to_bytes_be(self: &Self) -> Vec<u8>Returns the byte representation of the
BigUintin big-endian byte order.Examples
use BigUint; let i = parse_bytes.unwrap; assert_eq!;fn to_bytes_le(self: &Self) -> Vec<u8>Returns the byte representation of the
BigUintin little-endian byte order.Examples
use BigUint; let i = parse_bytes.unwrap; assert_eq!;fn to_u32_digits(self: &Self) -> Vec<u32>Returns the
u32digits representation of theBigUintordered least significant digit first.Examples
use BigUint; assert_eq!; assert_eq!; assert_eq!; assert_eq!;fn to_u64_digits(self: &Self) -> Vec<u64>Returns the
u64digits representation of theBigUintordered least significant digit first.Examples
use BigUint; assert_eq!; assert_eq!; assert_eq!; assert_eq!; assert_eq!;fn iter_u32_digits(self: &Self) -> U32Digits<'_>Returns an iterator of
u32digits representation of theBigUintordered least significant digit first.Examples
use BigUint; assert_eq!; assert_eq!; assert_eq!; assert_eq!;fn iter_u64_digits(self: &Self) -> U64Digits<'_>Returns an iterator of
u64digits representation of theBigUintordered least significant digit first.Examples
use BigUint; assert_eq!; assert_eq!; assert_eq!; assert_eq!; assert_eq!;fn to_str_radix(self: &Self, radix: u32) -> StringReturns the integer formatted as a string in the given radix.
radixmust be in the range2...36.Examples
use BigUint; let i = parse_bytes.unwrap; assert_eq!;fn to_radix_be(self: &Self, radix: u32) -> Vec<u8>Returns the integer in the requested base in big-endian digit order. The output is not given in a human readable alphabet but as a zero based
u8number.radixmust be in the range2...256.Examples
use BigUint; assert_eq!; // 0xFFFF = 65535 = 2*(159^2) + 94*159 + 27fn to_radix_le(self: &Self, radix: u32) -> Vec<u8>Returns the integer in the requested base in little-endian digit order. The output is not given in a human readable alphabet but as a zero based u8 number.
radixmust be in the range2...256.Examples
use BigUint; assert_eq!; // 0xFFFF = 65535 = 27 + 94*159 + 2*(159^2)fn bits(self: &Self) -> u64Determines the fewest bits necessary to express the
BigUint.fn pow(self: &Self, exponent: u32) -> SelfReturns
self ^ exponent.fn modpow(self: &Self, exponent: &Self, modulus: &Self) -> SelfReturns
(self ^ exponent) % modulus.Panics if the modulus is zero.
fn modinv(self: &Self, modulus: &Self) -> Option<Self>Returns the modular multiplicative inverse if it exists, otherwise
None.This solves for
xin the interval[0, modulus)such thatself * x ≡ 1 (mod modulus). The solution exists if and only ifgcd(self, modulus) == 1.use BigUint; use ; let m = from; // Trivial cases assert_eq!; assert_eq!; let neg1 = &m - 1u32; assert_eq!; let a = from; let x = a.modinv.unwrap; assert_eq!; assert_eq!; assert!;fn sqrt(self: &Self) -> SelfReturns the truncated principal square root of
self-- see Roots::sqrtfn cbrt(self: &Self) -> SelfReturns the truncated principal cube root of
self-- see Roots::cbrt.fn nth_root(self: &Self, n: u32) -> SelfReturns the truncated principal
nth root ofself-- see Roots::nth_root.fn trailing_zeros(self: &Self) -> Option<u64>Returns the number of least-significant bits that are zero, or
Noneif the entire number is zero.fn trailing_ones(self: &Self) -> u64Returns the number of least-significant bits that are ones.
fn count_ones(self: &Self) -> u64Returns the number of one bits.
fn bit(self: &Self, bit: u64) -> boolReturns whether the bit in the given position is set
fn set_bit(self: &mut Self, bit: u64, value: bool)Sets or clears the bit in the given position
Note that setting a bit greater than the current bit length, a reallocation may be needed to store the new digits
impl Add for BigUint
fn add(self: Self, other: &usize) -> BigUint
impl Add for BigUint
fn add(self: Self, other: u32) -> BigUint
impl Add for BigUint
fn add(self: Self, other: u64) -> BigUint
impl Add for BigUint
fn add(self: Self, other: u128) -> BigUint
impl Add for BigUint
fn add(self: Self, other: BigUint) -> BigUint
impl Add for BigUint
fn add(self: Self, other: &u128) -> BigUint
impl Add for BigUint
fn add(self: Self, other: u16) -> BigUint
impl Add for BigUint
fn add(self: Self, other: &u16) -> BigUint
impl Add for BigUint
fn add(self: Self, other: &u64) -> BigUint
impl Add for BigUint
fn add(self: Self, other: u8) -> BigUint
impl Add for BigUint
fn add(self: Self, other: usize) -> BigUint
impl Add for BigUint
fn add(self: Self, other: &u32) -> BigUint
impl Add for BigUint
fn add(self: Self, other: &BigUint) -> BigUint
impl Add for BigUint
fn add(self: Self, other: &u8) -> BigUint
impl AddAssign for BigUint
fn add_assign(self: &mut Self, other: u16)
impl AddAssign for BigUint
fn add_assign(self: &mut Self, other: BigUint)
impl AddAssign for BigUint
fn add_assign(self: &mut Self, other: &BigUint)
impl AddAssign for BigUint
fn add_assign(self: &mut Self, other: usize)
impl AddAssign for BigUint
fn add_assign(self: &mut Self, other: u32)
impl AddAssign for BigUint
fn add_assign(self: &mut Self, other: u64)
impl AddAssign for BigUint
fn add_assign(self: &mut Self, other: u128)
impl AddAssign for BigUint
fn add_assign(self: &mut Self, other: u8)
impl Binary for BigUint
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl BitAnd for BigUint
fn bitand(self: Self, other: BigUint) -> BigUint
impl BitAnd for BigUint
fn bitand(self: Self, other: &BigUint) -> BigUint
impl BitAndAssign for BigUint
fn bitand_assign(self: &mut Self, other: BigUint)
impl BitAndAssign for BigUint
fn bitand_assign(self: &mut Self, other: &BigUint)
impl BitOr for BigUint
fn bitor(self: Self, other: &BigUint) -> BigUint
impl BitOr for BigUint
fn bitor(self: Self, other: BigUint) -> BigUint
impl BitOrAssign for BigUint
fn bitor_assign(self: &mut Self, other: BigUint)
impl BitOrAssign for BigUint
fn bitor_assign(self: &mut Self, other: &BigUint)
impl BitXor for BigUint
fn bitxor(self: Self, other: &BigUint) -> BigUint
impl BitXor for BigUint
fn bitxor(self: Self, other: BigUint) -> BigUint
impl BitXorAssign for BigUint
fn bitxor_assign(self: &mut Self, other: BigUint)
impl BitXorAssign for BigUint
fn bitxor_assign(self: &mut Self, other: &BigUint)
impl CheckedAdd for BigUint
fn checked_add(self: &Self, v: &BigUint) -> Option<BigUint>
impl CheckedDiv for BigUint
fn checked_div(self: &Self, v: &BigUint) -> Option<BigUint>
impl CheckedEuclid for BigUint
fn checked_div_euclid(self: &Self, v: &BigUint) -> Option<BigUint>fn checked_rem_euclid(self: &Self, v: &BigUint) -> Option<BigUint>fn checked_div_rem_euclid(self: &Self, v: &Self) -> Option<(Self, Self)>
impl CheckedMul for BigUint
fn checked_mul(self: &Self, v: &BigUint) -> Option<BigUint>
impl CheckedSub for BigUint
fn checked_sub(self: &Self, v: &BigUint) -> Option<BigUint>
impl Clone for BigUint
fn clone(self: &Self) -> Selffn clone_from(self: &mut Self, other: &Self)
impl ConstZero for BigUint
impl Debug for BigUint
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for BigUint
fn default() -> BigUint
impl Display for BigUint
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Div for BigUint
fn div(self: Self, other: u64) -> BigUint
impl Div for BigUint
fn div(self: Self, other: u32) -> BigUint
impl Div for BigUint
fn div(self: Self, other: u8) -> BigUint
impl Div for BigUint
fn div(self: Self, other: usize) -> BigUint
impl Div for BigUint
fn div(self: Self, other: &u128) -> BigUint
impl Div for BigUint
fn div(self: Self, other: &u8) -> BigUint
impl Div for BigUint
fn div(self: Self, other: &usize) -> BigUint
impl Div for BigUint
fn div(self: Self, other: &u64) -> BigUint
impl Div for BigUint
fn div(self: Self, other: &u32) -> BigUint
impl Div for BigUint
fn div(self: Self, other: BigUint) -> BigUint
impl Div for BigUint
fn div(self: Self, other: &BigUint) -> BigUint
impl Div for BigUint
fn div(self: Self, other: u16) -> BigUint
impl Div for BigUint
fn div(self: Self, other: u128) -> BigUint
impl Div for BigUint
fn div(self: Self, other: &u16) -> BigUint
impl DivAssign for BigUint
fn div_assign(self: &mut Self, other: u128)
impl DivAssign for BigUint
fn div_assign(self: &mut Self, other: u64)
impl DivAssign for BigUint
fn div_assign(self: &mut Self, other: u8)
impl DivAssign for BigUint
fn div_assign(self: &mut Self, other: u32)
impl DivAssign for BigUint
fn div_assign(self: &mut Self, other: u16)
impl DivAssign for BigUint
fn div_assign(self: &mut Self, other: &BigUint)
impl DivAssign for BigUint
fn div_assign(self: &mut Self, other: usize)
impl DivAssign for BigUint
fn div_assign(self: &mut Self, other: BigUint)
impl Eq for BigUint
impl Euclid for BigUint
fn div_euclid(self: &Self, v: &BigUint) -> BigUintfn rem_euclid(self: &Self, v: &BigUint) -> BigUintfn div_rem_euclid(self: &Self, v: &Self) -> (Self, Self)
impl Freeze for BigUint
impl From for BigUint
fn from(x: bool) -> Self
impl From for BigUint
fn from(n: u8) -> Self
impl From for BigUint
fn from(n: u16) -> Self
impl From for BigUint
fn from(n: u32) -> Self
impl From for BigUint
fn from(n: u64) -> Self
impl From for BigUint
fn from(n: usize) -> Self
impl From for BigUint
fn from(n: u128) -> Self
impl FromBytes for BigUint
fn from_be_bytes(bytes: &<Self as >::Bytes) -> Selffn from_le_bytes(bytes: &<Self as >::Bytes) -> Self
impl FromPrimitive for BigUint
fn from_i64(n: i64) -> Option<BigUint>fn from_i128(n: i128) -> Option<BigUint>fn from_u64(n: u64) -> Option<BigUint>fn from_u128(n: u128) -> Option<BigUint>fn from_f64(n: f64) -> Option<BigUint>
impl FromStr for BigUint
fn from_str(s: &str) -> Result<BigUint, ParseBigIntError>
impl Hash for BigUint
fn hash<H: hash::Hasher>(self: &Self, state: &mut H)
impl Integer for BigUint
fn div_rem(self: &Self, other: &BigUint) -> (BigUint, BigUint)fn div_floor(self: &Self, other: &BigUint) -> BigUintfn mod_floor(self: &Self, other: &BigUint) -> BigUintfn div_mod_floor(self: &Self, other: &BigUint) -> (BigUint, BigUint)fn div_ceil(self: &Self, other: &BigUint) -> BigUintfn gcd(self: &Self, other: &Self) -> SelfCalculates the Greatest Common Divisor (GCD) of the number and
other.The result is always positive.
fn lcm(self: &Self, other: &BigUint) -> BigUintCalculates the Lowest Common Multiple (LCM) of the number and
other.fn gcd_lcm(self: &Self, other: &Self) -> (Self, Self)Calculates the Greatest Common Divisor (GCD) and Lowest Common Multiple (LCM) together.
fn divides(self: &Self, other: &BigUint) -> boolDeprecated, use
is_multiple_ofinstead.fn is_multiple_of(self: &Self, other: &BigUint) -> boolReturns
trueif the number is a multiple ofother.fn is_even(self: &Self) -> boolReturns
trueif the number is divisible by2.fn is_odd(self: &Self) -> boolReturns
trueif the number is not divisible by2.fn next_multiple_of(self: &Self, other: &Self) -> SelfRounds up to nearest multiple of argument.
fn prev_multiple_of(self: &Self, other: &Self) -> SelfRounds down to nearest multiple of argument.
fn dec(self: &mut Self)fn inc(self: &mut Self)
impl LowerHex for BigUint
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Mul for BigUint
fn mul(self: Self, other: &u64) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: u8) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: usize) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: &BigUint) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: &u32) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: &u8) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: &usize) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: u32) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: u64) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: u128) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: BigUint) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: &u128) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: u16) -> BigUint
impl Mul for BigUint
fn mul(self: Self, other: &u16) -> BigUint
impl MulAssign for BigUint
fn mul_assign(self: &mut Self, other: u8)
impl MulAssign for BigUint
fn mul_assign(self: &mut Self, other: BigUint)
impl MulAssign for BigUint
fn mul_assign(self: &mut Self, other: u16)
impl MulAssign for BigUint
fn mul_assign(self: &mut Self, other: &BigUint)
impl MulAssign for BigUint
fn mul_assign(self: &mut Self, other: usize)
impl MulAssign for BigUint
fn mul_assign(self: &mut Self, other: u32)
impl MulAssign for BigUint
fn mul_assign(self: &mut Self, other: u64)
impl MulAssign for BigUint
fn mul_assign(self: &mut Self, other: u128)
impl Num for BigUint
fn from_str_radix(s: &str, radix: u32) -> Result<BigUint, ParseBigIntError>Creates and initializes a
BigUint.
impl Octal for BigUint
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl One for BigUint
fn one() -> BigUintfn set_one(self: &mut Self)fn is_one(self: &Self) -> bool
impl Ord for BigUint
fn cmp(self: &Self, other: &BigUint) -> Ordering
impl PartialEq for BigUint
fn eq(self: &Self, other: &BigUint) -> bool
impl PartialOrd for BigUint
fn partial_cmp(self: &Self, other: &BigUint) -> Option<Ordering>
impl Pow for BigUint
fn pow(self: Self, exp: u8) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: usize) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: &u16) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: &u128) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: u16) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: u128) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: &u32) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: u32) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: BigUint) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: &u64) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: &BigUint) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: u64) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: &u8) -> BigUint
impl Pow for BigUint
fn pow(self: Self, exp: &usize) -> BigUint
impl RefUnwindSafe for BigUint
impl Rem for BigUint
fn rem(self: Self, other: &u32) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: u8) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: usize) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: &u128) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: &u8) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: &usize) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: &u64) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: u32) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: BigUint) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: &BigUint) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: u16) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: u128) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: &u16) -> BigUint
impl Rem for BigUint
fn rem(self: Self, other: u64) -> BigUint
impl RemAssign for BigUint
fn rem_assign(self: &mut Self, other: u128)
impl RemAssign for BigUint
fn rem_assign(self: &mut Self, other: u64)
impl RemAssign for BigUint
fn rem_assign(self: &mut Self, other: u8)
impl RemAssign for BigUint
fn rem_assign(self: &mut Self, other: u32)
impl RemAssign for BigUint
fn rem_assign(self: &mut Self, other: u16)
impl RemAssign for BigUint
fn rem_assign(self: &mut Self, other: &BigUint)
impl RemAssign for BigUint
fn rem_assign(self: &mut Self, other: usize)
impl RemAssign for BigUint
fn rem_assign(self: &mut Self, other: BigUint)
impl Roots for BigUint
fn nth_root(self: &Self, n: u32) -> Selffn sqrt(self: &Self) -> Selffn cbrt(self: &Self) -> Self
impl Send for BigUint
impl Serialize for BigUint
fn serialize<S>(self: &Self, serializer: S) -> Result<<S as >::Ok, <S as >::Error> where S: Serializer
impl Shl for BigUint
fn shl(self: Self, rhs: u8) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: u64) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: i8) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: i64) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &u16) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &u128) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &i16) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &i128) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: u16) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: u128) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: i16) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: i128) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &u32) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &usize) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &i32) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &isize) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: u32) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: usize) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: i32) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: isize) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &u8) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &u64) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &i8) -> BigUint
impl Shl for BigUint
fn shl(self: Self, rhs: &i64) -> BigUint
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: u8)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: u64)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: i8)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: i64)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &u16)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &u128)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &i16)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &i128)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: u16)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: u128)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: i16)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: i128)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &u32)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &usize)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &i32)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &isize)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: u32)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: usize)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: i32)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: isize)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &u8)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &u64)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &i8)
impl ShlAssign for BigUint
fn shl_assign(self: &mut Self, rhs: &i64)
impl Shr for BigUint
fn shr(self: Self, rhs: u16) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: u128) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: i16) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: i128) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &u32) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &usize) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &i32) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &isize) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: u32) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: usize) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: i32) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: isize) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &u8) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &u64) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &i8) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &i64) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: u8) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: u64) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: i8) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: i64) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &u16) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &u128) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &i16) -> BigUint
impl Shr for BigUint
fn shr(self: Self, rhs: &i128) -> BigUint
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: u16)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: u128)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: i16)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: i128)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &u32)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &usize)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &i32)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &isize)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: u32)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: usize)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: i32)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: isize)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &u8)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &u64)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &i8)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &i64)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: u8)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: u64)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: i8)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: i64)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &u16)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &u128)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &i16)
impl ShrAssign for BigUint
fn shr_assign(self: &mut Self, rhs: &i128)
impl Sub for BigUint
fn sub(self: Self, other: BigUint) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: u16) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: u128) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: &u16) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: u64) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: u32) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: u8) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: usize) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: &u128) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: &u8) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: &usize) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: &u64) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: &u32) -> BigUint
impl Sub for BigUint
fn sub(self: Self, other: &BigUint) -> BigUint
impl SubAssign for BigUint
fn sub_assign(self: &mut Self, other: usize)
impl SubAssign for BigUint
fn sub_assign(self: &mut Self, other: BigUint)
impl SubAssign for BigUint
fn sub_assign(self: &mut Self, other: &BigUint)
impl SubAssign for BigUint
fn sub_assign(self: &mut Self, other: u128)
impl SubAssign for BigUint
fn sub_assign(self: &mut Self, other: u64)
impl SubAssign for BigUint
fn sub_assign(self: &mut Self, other: u8)
impl SubAssign for BigUint
fn sub_assign(self: &mut Self, other: u32)
impl SubAssign for BigUint
fn sub_assign(self: &mut Self, other: u16)
impl Sync for BigUint
impl ToBigInt for BigUint
fn to_bigint(self: &Self) -> Option<BigInt>
impl ToBigUint for BigUint
fn to_biguint(self: &Self) -> Option<BigUint>
impl ToBytes for BigUint
fn to_be_bytes(self: &Self) -> <Self as >::Bytesfn to_le_bytes(self: &Self) -> <Self as >::Bytes
impl ToPrimitive for BigUint
fn to_i64(self: &Self) -> Option<i64>fn to_i128(self: &Self) -> Option<i128>fn to_u64(self: &Self) -> Option<u64>fn to_u128(self: &Self) -> Option<u128>fn to_f32(self: &Self) -> Option<f32>fn to_f64(self: &Self) -> Option<f64>
impl TryFrom for BigUint
fn try_from(value: BigInt) -> Result<BigUint, TryFromBigIntError<BigInt>>
impl TryFrom for BigUint
fn try_from(value: i32) -> Result<BigUint, TryFromBigIntError<()>>
impl TryFrom for BigUint
fn try_from(value: &BigInt) -> Result<BigUint, TryFromBigIntError<()>>
impl TryFrom for BigUint
fn try_from(value: i16) -> Result<BigUint, TryFromBigIntError<()>>
impl TryFrom for BigUint
fn try_from(value: i8) -> Result<BigUint, TryFromBigIntError<()>>
impl TryFrom for BigUint
fn try_from(value: i128) -> Result<BigUint, TryFromBigIntError<()>>
impl TryFrom for BigUint
fn try_from(value: isize) -> Result<BigUint, TryFromBigIntError<()>>
impl TryFrom for BigUint
fn try_from(value: i64) -> Result<BigUint, TryFromBigIntError<()>>
impl Unpin for BigUint
impl UnsafeUnpin for BigUint
impl Unsigned for BigUint
impl UnwindSafe for BigUint
impl UpperHex for BigUint
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Zero for BigUint
fn zero() -> BigUintfn set_zero(self: &mut Self)fn is_zero(self: &Self) -> bool
impl<'de> Deserialize for BigUint
fn deserialize<D>(deserializer: D) -> Result<Self, <D as >::Error> where D: Deserializer<'de>
impl<I> Average for BigUint
fn average_floor(self: &Self, other: &I) -> IReturns the floor value of the average of
selfandother.fn average_ceil(self: &Self, other: &I) -> IReturns the ceil value of the average of
selfandother.
impl<T> Any for BigUint
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for BigUint
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for BigUint
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for BigUint
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> DeserializeOwned for BigUint
impl<T> From for BigUint
fn from(t: T) -> TReturns the argument unchanged.
impl<T> NumAssign for BigUint
impl<T> NumAssignRef for BigUint
impl<T> NumRef for BigUint
impl<T> Product for BigUint
fn product<I>(iter: I) -> Self where I: Iterator<Item = T>
impl<T> Sum for BigUint
fn sum<I>(iter: I) -> Self where I: Iterator<Item = T>
impl<T> ToOwned for BigUint
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for BigUint
fn to_string(self: &Self) -> String
impl<T, Base> RefNum for BigUint
impl<T, Rhs> NumAssignOps for BigUint
impl<T, Rhs, Output> NumOps for BigUint
impl<T, U> Into for BigUint
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for BigUint
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for BigUint
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>